@@ -2,8 +2,11 @@
 
     """
 
+import sys
+
 from .auto import ret_module_2_run_name
 
 
 if __name__ == '__main__' :
-    ret_module_2_run_name()
+    conf_fp = sys.argv[1]
+    ret_module_2_run_name(conf_fp)
